@@ -17,9 +17,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-boolean ppc64_elf_mark_entry_syms
+bfd_boolean ppc64_elf_mark_entry_syms
   PARAMS ((struct bfd_link_info *));
-boolean ppc64_elf_edit_opd
+bfd_boolean ppc64_elf_edit_opd
   PARAMS ((bfd *, struct bfd_link_info *));
 bfd_vma ppc64_elf_toc
   PARAMS ((bfd *));
@@ -27,8 +27,8 @@ int ppc64_elf_setup_section_lists
   PARAMS ((bfd *, struct bfd_link_info *));
 void ppc64_elf_next_input_section
   PARAMS ((struct bfd_link_info *, asection *));
-boolean ppc64_elf_size_stubs
+bfd_boolean ppc64_elf_size_stubs
   PARAMS ((bfd *, bfd *, struct bfd_link_info *, bfd_signed_vma,
 	   asection *(*) (const char *, asection *), void (*) (void)));
-boolean ppc64_elf_build_stubs
+bfd_boolean ppc64_elf_build_stubs
   PARAMS ((struct bfd_link_info *));
